@@ -192,19 +192,27 @@ func (r *ReconcileClusterStorage) Reconcile(request reconcile.Request) (reconcil
 var (
 	unavailable = configv1.ClusterOperatorStatusCondition{
 		Type:   configv1.OperatorAvailable,
+		Reason: "AsExpected",
 		Status: configv1.ConditionFalse,
 	}
 	notDegraded = configv1.ClusterOperatorStatusCondition{
 		Type:   configv1.OperatorDegraded,
+		Reason: "AsExpected",
 		Status: configv1.ConditionFalse,
 	}
 	notProgressing = configv1.ClusterOperatorStatusCondition{
 		Type:   configv1.OperatorProgressing,
+		Reason: "AsExpected",
+		Status: configv1.ConditionFalse,
+	}
+	notUpgradeable = configv1.ClusterOperatorStatusCondition{
+		Type:   configv1.OperatorUpgradeable,
+		Reason: "AsExpected",
 		Status: configv1.ConditionFalse,
 	}
 )
 
-// setStatusProgressing sets Available=false;Degraded=false;Progressing=true
+// setStatusProgressing sets Available=false;Degraded=false;Progressing=true;Upgradeable=false
 // we set "progressing" if the cluster operator's version is not the latest
 // and we are about to try to roll it out
 func (r *ReconcileClusterStorage) setStatusProgressing(clusterOperator *configv1.ClusterOperator) error {
@@ -222,9 +230,11 @@ func (r *ReconcileClusterStorage) setStatusProgressing(clusterOperator *configv1
 
 	v1helpers.SetStatusCondition(&clusterOperator.Status.Conditions, unavailable)
 	v1helpers.SetStatusCondition(&clusterOperator.Status.Conditions, notDegraded)
+	v1helpers.SetStatusCondition(&clusterOperator.Status.Conditions, notUpgradeable)
 
 	progressing := configv1.ClusterOperatorStatusCondition{
 		Type:   configv1.OperatorProgressing,
+		Reason: "AsExpected",
 		Status: configv1.ConditionTrue,
 	}
 	if len(releaseVersion) > 0 {
@@ -232,6 +242,8 @@ func (r *ReconcileClusterStorage) setStatusProgressing(clusterOperator *configv1
 	}
 	v1helpers.SetStatusCondition(&clusterOperator.Status.Conditions, progressing)
 
+	clusterOperator.Status.RelatedObjects = getRelatedObjects(nil)
+
 	updateErr := r.client.Status().Update(context.TODO(), clusterOperator)
 	if updateErr != nil {
 		log.Error(updateErr, "Failed to update ClusterOperator status")
@@ -240,8 +252,8 @@ func (r *ReconcileClusterStorage) setStatusProgressing(clusterOperator *configv1
 	return nil
 }
 
-// syncStatus will set either Available=true;Degraded=false;Progressing=false
-// or Available=false;Degraded=true;Progressing=false depending on the error
+// syncStatus will set either Available=true;Degraded=false;Progressing=false;Upgradeable=true
+// or Available=false;Degraded=true;Progressing=false;Upgradeable=false depending on the error
 func (r *ReconcileClusterStorage) syncStatus(clusterOperator *configv1.ClusterOperator, err error) error {
 	// we set versions if we are "available" to indicate we have rolled out the latest
 	// version of the cluster storage object
@@ -268,6 +280,7 @@ func (r *ReconcileClusterStorage) syncStatus(clusterOperator *configv1.ClusterOp
 			}
 			v1helpers.SetStatusCondition(&clusterOperator.Status.Conditions, degraded)
 			v1helpers.SetStatusCondition(&clusterOperator.Status.Conditions, unavailable)
+			v1helpers.SetStatusCondition(&clusterOperator.Status.Conditions, notUpgradeable)
 
 			updateErr := r.client.Status().Update(context.TODO(), clusterOperator)
 			if updateErr != nil {
@@ -281,13 +294,22 @@ func (r *ReconcileClusterStorage) syncStatus(clusterOperator *configv1.ClusterOp
 
 	available := configv1.ClusterOperatorStatusCondition{
 		Type:   configv1.OperatorAvailable,
+		Reason: "AsExpected",
 		Status: configv1.ConditionTrue,
 	}
 	if message != "" {
 		available.Message = message
 	}
+
+	upgradeable := configv1.ClusterOperatorStatusCondition{
+		Type:   configv1.OperatorUpgradeable,
+		Reason: "AsExpected",
+		Status: configv1.ConditionTrue,
+	}
+
 	v1helpers.SetStatusCondition(&clusterOperator.Status.Conditions, available)
 	v1helpers.SetStatusCondition(&clusterOperator.Status.Conditions, notDegraded)
+	v1helpers.SetStatusCondition(&clusterOperator.Status.Conditions, upgradeable)
 
 	updateErr := r.client.Status().Update(context.TODO(), clusterOperator)
 	if updateErr != nil {
@@ -303,6 +325,8 @@ func newStorageClassForCluster(infrastructure *configv1.Infrastructure) (*storag
 		return resourceread.ReadStorageClassV1OrDie(generated.MustAsset("assets/aws.yaml")), nil
 	case configv1.AzurePlatformType:
 		return resourceread.ReadStorageClassV1OrDie(generated.MustAsset("assets/azure.yaml")), nil
+	case configv1.GCPPlatformType:
+		return resourceread.ReadStorageClassV1OrDie(generated.MustAsset("assets/gcp.yaml")), nil
 	case configv1.OpenStackPlatformType:
 		return resourceread.ReadStorageClassV1OrDie(generated.MustAsset("assets/openstack.yaml")), nil
 	case configv1.VSpherePlatformType:
